@@ -2,7 +2,8 @@
 
 package Msql;
 
-BEGIN { require 5.004 };
+use 5.004;
+use strict;
 
 require Carp;
 require DynaLoader;
@@ -16,7 +17,7 @@ use vars qw($QUIET @ISA @EXPORT @EXPORT_OK $VERSION $db_errstr);
 $db_errstr = '';
 $QUIET  = 0;
 @ISA    = qw(DBI); # Inherits Exporter and DynaLoader via DBI
-$VERSION = '1.2001';
+$VERSION = '1.2004';
 
 # @EXPORT is a relict from old times...
 @EXPORT = qw(
@@ -83,11 +84,13 @@ sub connect ($;$$$$) {
     bless($self, $class);
     $self->{'drh'} = DBI->install_driver($self->{'driver'});
     if ($db) {
-	my($dsn) = "DBI:mSQL:database=$db;host=$host";
-	if (!($self->{'dbh'} = $class->SUPER::connect($dsn, $user, $password))) {
+	my $dsn = "DBI:mSQL:database=$db;host=$host";
+	my $dbh = $class->SUPER::connect($dsn, $user, $password);
+	if (!$dbh) {
 	    $db_errstr = $DBI::errstr;
 	    return undef;
 	}
+	$self->{'dbh'} = $dbh;
 	$dbh->{'CompatMode'} = 1;
 	$dbh->{'PrintError'} = !$Msql::QUIET;
     }
@@ -119,10 +122,15 @@ sub listtables ($) {
     $self->{'dbh'}->func('_ListTables');
 }
 
-sub quote ($$) { my($self) = shift; $self->{'dbh'}->quote(@_); }
+sub quote ($$) {
+    my($self) = shift;
+    my $obj = (ref($self) && $self->{'dbh'}) ?
+	$self->{'dbh'} : 'DBD::mSQL::db';
+    $obj->quote(shift);
+}
 
 sub errmsg ($) {
-    my($self) = shift;
+    my $self = shift;
     if (!ref($self)) {
 	$DBI::errstr || $db_errstr;
     } elsif ($self->{'dbh'}) {
@@ -133,6 +141,7 @@ sub errmsg ($) {
 }
 
 sub errno ($) {
+    my $self = shift;
     if ($self->{'dbh'}) {
 	$self->{'dbh'}->err();
     } else {
@@ -199,9 +208,10 @@ sub sockfd ($) { shift->{'dbh'}->{'sockfd'} }
 
 
 sub AUTOLOAD {
-    my $meth = $AUTOLOAD;
+    my $meth = $Msql::AUTOLOAD;
     my $converted = 0;
 
+    my $class;
     if ($meth =~ /(.*)::(.*)/) {
 	$meth = $2;
 	$class = $1;
@@ -213,7 +223,7 @@ sub AUTOLOAD {
     TRY: {
 	my $val = DBD::mSQL::constant($meth, @_ ? $_[0] : 0);
 	if ($! == 0) {
-	    eval "sub $AUTOLOAD { $val }";
+	    eval "sub $Msql::AUTOLOAD { $val }";
 	    return $val;
 	}
 
@@ -224,6 +234,7 @@ sub AUTOLOAD {
 	}
 
 	if (defined &$meth) {
+	    no strict 'refs';
 	    *$meth = \&{$meth};
 	    return &$meth(@_);
 	} elsif ($meth =~ s/(.*)type$/uc($1)."_TYPE"/e) {
@@ -235,7 +246,7 @@ sub AUTOLOAD {
 	}
     }
 
-  Carp::croak("$AUTOLOAD: Not defined in $class and not"
+  Carp::croak("$Msql::AUTOLOAD: Not defined in $class and not"
 	      . " autoloadable (last try $meth)");
 }
 
