@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.0201';
+$VERSION = '2.0204';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -59,7 +59,7 @@ sub _OdbcParse($$$) {
 	if ($val =~ /([^=]*)=(.*)/) {
 	    $var = $1;
 	    $val = $2;
-	    if ($var eq 'hostname'  ||  $var eq 'host') {
+	    if ($var eq 'hostname') {
 		$hash->{'host'} = $val;
 	    } elsif ($var eq 'db'  ||  $var eq 'dbname') {
 		$hash->{'database'} = $val;
@@ -214,9 +214,7 @@ sub prepare {
     my($dbh, $statement)= @_;
 
     # create a 'blank' dbh
-    my $sth = DBI::_new_sth($dbh, {
-	'Statement' => $statement,
-    });
+    my $sth = DBI::_new_sth($dbh, {'Statement' => $statement});
 
     # Populate internal handle data.
     if (!DBD::mSQL::st::_prepare($sth, $statement)) {
