@@ -8,9 +8,7 @@
  *  Copyright (c) 1994,1995  Tim Bunce
  *
  *  You may distribute this under the terms of either the GNU General Public
- *  License or the Artistic License, as specified in the Perl README file,
- *  with the exception that it cannot be placed on a CD-ROM or similar media
- *  for commercial distribution without the prior approval of the author.
+ *  License or the Artistic License, as specified in the Perl README file.
  *
  *  Author:  Jochen Wiedmann
  *           Am Eisteich 9
@@ -26,7 +24,6 @@
 
 
 #include "dbdimp.h"
-
 #include "bindparam.h"
 
 
@@ -725,6 +722,8 @@ int dbd_st_internal_execute(SV* h, SV* statement, SV* attribs, int numParams,
 	}
     }
 
+    if (*cdaPtr) { MyFreeResult(*cdaPtr); *cdaPtr = NULL; }
+
     if (slen >= 10
 	&&  tolower(sbuf[0]) == 'l'
 	&&  tolower(sbuf[1]) == 'i'
@@ -822,20 +821,32 @@ int dbd_st_internal_execute(SV* h, SV* statement, SV* attribs, int numParams,
     if ((MyQuery(svsock, sbuf, slen) == -1)  &&
 	(!MyReconnect(svsock, h)
 	 ||	 (MyQuery(svsock, sbuf, slen) == -1))) {
+#ifdef DEBUGGING_MEMLEAK
+	if (salloc) printf("Freeing ParseParam: %08x\n", (unsigned int) salloc);
+#endif
         Safefree(salloc);
 	DO_ERROR(h, JW_ERR_QUERY, svsock);
 	return -2;
     }
+#ifdef DEBUGGING_MEMLEAK
+    if (salloc) printf("Freeing ParseParam: %08x\n", (unsigned int) salloc);
+#endif
     Safefree(salloc);
 
     /** Store the result from the Query */
 #if defined(DBD_MYSQL)
+#ifdef DEBUGGING_MEMLEAK
+    printf("Allocating result, old = %08x\n", *cdaPtr);
+#endif
     if (!(*cdaPtr = (use_mysql_use_result ?
 		     mysql_use_result(svsock) : mysql_store_result(svsock)))) {
         return mysql_affected_rows(svsock);
 #elif defined(DBD_MSQL)
     if (!(*cdaPtr = MyStoreResult(svsock))) {
         return -1;
+#endif
+#ifdef DEBUGGING_MEMLEAK
+    printf("Allocated result %08x\n", *cdaPtr);
 #endif
     }
 
@@ -961,7 +972,11 @@ AV* dbd_st_fetch(SV* sth, imp_sth_t* imp_sth) {
     AV *av;
     row_t cols;
 #if defined(DBD_MYSQL)
+#if (defined(MYSQL_VERSION_ID)  &&  (MYSQL_VERSION_ID > 32204))
+    unsigned long* lengths;
+#else
     unsigned int* lengths;
+#endif
 #endif
 
     ChopBlanks = DBIc_is(imp_sth, DBIcf_ChopBlanks);
@@ -1049,6 +1064,9 @@ int dbd_st_finish(SV* sth, imp_sth_t* imp_sth) {
     /* We don't close the cursor till DESTROY.                  */
     /* The application may re execute it.                       */
     if (imp_sth && imp_sth->cda) {
+#ifdef DEBUGGING_MEMLEAK
+        printf("Freeing result, old = %08x\n", imp_sth->cda);
+#endif
         MyFreeResult(imp_sth->cda);
 	imp_sth->cda = NULL;
     }
